Prints the final trial summary and reports how many interim looks were completed when survival_adapt returns a goldilocks_trial object.
Usage
# S3 method for class 'goldilocks_trial'
print(x, ...)Prints the final trial summary and reports how many interim looks were completed when survival_adapt returns a goldilocks_trial object.
# S3 method for class 'goldilocks_trial'
print(x, ...)