Cumulative distribution function of the PWE for a vectorized hazard rate parameter
Source:R/pwe.R
ppwe.RdExtends PWEALL::pwe() to allow for vectorization over the
hazard rates.
Arguments
- hazard
matrix. A matrix of hazard rate parameters with number of columns one greater than the length of the
cutpointsvector. The number of rows can be anything, and is typically dictated by the number of MCMC draws.- end_of_study
finite positive time at which the cumulative event probability is evaluated. It must be greater than every cutpoint.
- cutpoints
finite, positive, strictly increasing vector of interior times at which the hazard rate changes. The number of hazard rates must be one greater than the number of cutpoints. Use
NULLfor a constant hazard.