Cumulative distribution function of the PWE for a vectorized hazard rate parameter
Source:R/pwe.R
ppwe.RdExtends the pwe function to allow for
vectorization over the hazard rates.
Arguments
- hazard
matrix. A matrix of hazard rate parameters with number of columns equal to the length of the
cutpointsvector. The number of rows can be anything, and is typically dictated by the number of MCMC draws.- end_of_study
scalar. Length of the study; i.e. time at which endpoint will be evaluated.
- cutpoints
vector. The change-point vector indicating time when the hazard rates change. Note the first element of
cutpointsshould always be 0.