Summarize simulations to get operating characteristics
Arguments
- data
list (of data frames) or a single data frame. If summarizing a single run of simulations,
datawill be adata.frameobject returned fromsurvival_adapt. If summarizing multiple simulation scenarios,datawill be alistobject, with each element being adata.frameobject.
Value
Data frame reporting the operating characteristics, including the power (which will be equal to the type I error in the null case); the proportion of trials that stopped for early expected success, futility, or went to the maximum sample size. The average stopping sample size (and standard deviation) are also recorded. The proportion of trials that stopped early for expected success, yet went to ultimately fail are also reported.